@@ -9,7 +9,7 @@ use parent qw/Cache::Memcached::Fast/;
 use POSIX::AtFork;
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $SANITIZE_METHOD = sub {
     my $key = shift;
     $key = uri_escape($key,"\x00-\x20\x7f-\xff");
@@ -31,7 +31,7 @@ sub new {
     $mem;
 }
 
-for my $method ( qw/set cas add replace append prepend incr decr delete/ ) {
+for my $method ( qw/set cas add replace append prepend incr decr delete touch/ ) {
     no strict 'refs';
     my $super = 'SUPER::'.$method;
     *{$method} = sub {
@@ -40,7 +40,7 @@ for my $method ( qw/set cas add replace append prepend incr decr delete/ ) {
         $self->$super($SANITIZE_METHOD->($key), @_);
     };
 }
-for my $method (qw/set_multi  cas_multi add_multi replace_multi append_multi prepend_multi incr_multi decr_multi delete_multi/ ) {
+for my $method (qw/set_multi  cas_multi add_multi replace_multi append_multi prepend_multi incr_multi decr_multi delete_multi touch_multi/ ) {
     no strict 'refs';
     my $super = 'SUPER::'.$method;
     *{$method} = sub {
